#ifndef NT2_INCLUDE_FUNCTIONS_PINV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PINV_HPP_INCLUDED

#include <nt2/linalg/include/functions/pinv.hpp>

#endif
